<?php

/**
 * Class for SAML 2 authentication request messages.
 *
 * @package simpleSAMLphp
 * @version $Id$
 */
class SAML2_StorkAuthnRequest extends SAML2\AuthnRequest {

    /**
     * Constructor for SAML 2 authentication request messages.
     *
     * @param DOMElement|NULL $xml  The input message.
     */
    public function __construct(DOMElement $xml = NULL) {
        parent::__construct();
    }

    /**
     * Convert this authentication request to an XML element.
     *
     * @return DOMElement  This authentication request.
     */
    public function toUnsignedXML() {
        $root = parent::toUnsignedXML();
        /* Ugly hack to add another namespace declaration to the root element. */
        //$root->setAttributeNS('urn:eu:stork:names:tc:STORK:1.0:protocol', 'storkp:tmp', 'tmp');
        //$root->removeAttributeNS('urn:eu:stork:names:tc:STORK:1.0:protocol', 'tmp');
        //$root->setAttributeNS('urn:eu:stork:names:tc:STORK:1.0:assertion', 'stork:tmp', 'tmp');
        //$root->removeAttributeNS('urn:eu:stork:names:tc:STORK:1.0:assertion', 'tmp');

        $root->setAttribute('AssertionConsumerServiceURL', StorkConstants::ASSERTION_URL);
        $root->setAttribute('ProviderName', StorkConstants::SPID);
        
        $exts = parent::getExtensions();
        if (!empty($exts)) {
            $exts2 = $this->getParsedExtensions($exts);
            try {
                $oldNode = $this->document->getElementsByTagNameNS('urn:oasis:names:tc:SAML:2.0:protocol',
                        'Extensions');
                foreach ($oldNode as $link) {
                    $this->document->firstChild->removeChild($link);
                }
                
                $root->appendChild($exts2);
            } catch(Exception $e) {
                echo 'Exception: ' . $e->getMessage();
            }
        }

        return $root;
    }

    public function setExtensions($extensions) {
      assert('is_array($extensions)');
      $this->extensions = $extensions;
    }

    /**
   * Get the Extensions.
   *
   * @param array|NULL $extensions The Extensions.
   */
  public function getExtensions() {
    return getParsedExtensions($this->extensions);
  }
    
  /**
   * Get the Extensions.
   *
   * @param array|NULL $extensions The Extensions.
   */
  public function getParsedExtensions($exts) {
    $extension = $this->document->createElementNS(StorkConstants::SAMLP_NS, 'samlp:Extensions');
    
    $auth = $this->document->createElementNS(StorkConstants::STORKP_NS, 'storkp:AuthenticationAttributes');
    $vidp = $this->document->createElementNS(StorkConstants::STORKP_NS, 'storkp:VIDPAuthenticationAttributes');
    $attrs = $this->document->createElementNS(StorkConstants::STORKP_NS, 'storkp:RequestedAttributes');
    
    foreach($exts as $key => $value) {
      if (strncmp($key, "RequestedAttribute", 18) === 0) {
        $attrs->appendChild($value->toXML($extension));
        $extension->appendChild($attrs);
      } else if ($key === "VIDPspid") {
        $spinfo = $this->document->createElementNS(StorkConstants::STORKP_NS, 'storkp:SPInformation');
        $spinfo->appendChild($value->toXML($extension));
        $vidp->appendChild($spinfo);
        $auth->appendChild($vidp);
        $extension->appendChild($auth);
      } else {
        if ($value instanceof SAML2\XML\Chunk) {
            $extension->appendChild($value->toXML($extension));
        } else if ($value instanceof String) {
            $ns = null;
            if (strpos($key, 'storkp:') === 0 ) {
              $ns = StorkConstants::STORKP_NS;
            } else if (strpos($key, 'stork:') === 0) {
              $ns = StorkConstants::STORK_NS;
            } else {
               SimpleSAML_Logger::error("THIS SHOULND'T HAPPEN!!\nCaused by key: ".$key);
            }
            $doc = $extension->ownerDocument;
            $n = $doc->createElementNS($ns, $key);
            $n->appendChild($doc->createTextNode($value));
            $extension->appendChild($n);
        }
      }
    }
    
    SimpleSAML_Logger::debug($extension->ownerDocument->saveXML());
    return $extension;
  }
}

?>
